@@ -15,6 +15,32 @@ from typing import (
 )
 from weakref import ref
 
+_VOID = {
+    "area",
+    "base",
+    "basefont",
+    "bgsound",
+    "br",
+    "col",
+    "command",
+    "embed",
+    "frame",
+    "hr",
+    "image",
+    "img",
+    "input",
+    "isindex",
+    "keygen",
+    "link",
+    "menuitem",
+    "meta",
+    "nextid",
+    "param",
+    "source",
+    "track",
+    "wbr",
+}
+
 
 class ParseError(Exception):
     pass
@@ -125,8 +151,8 @@ def unparse(node: Node) -> str:
         )
         for child in node.children
     )
-    if kids:
-        return f"<{node.tag} {attrs}>{kids}</{node.tag}>"
-    else:
+    if node.tag in _VOID:
         return f"<{node.tag} {attrs}/>"
+    else:
+        return f"<{node.tag} {attrs}>{kids}</{node.tag}>"
 
